%% Figure 2: Show Grid-Factory Routines
% This script produces the contents of Figure 2, i.e., it shows four
% examples of grid-factory routines
%
% * a rectilinear grid created by tensorGrid
% * a 2.5D PEBI grid created from the seamount.mat dataset
% * a corner-point grid with a single fault
% * a realistic geological model (data set supplied with MRST)

%% Rectilinear grid
clf
dx = 1-0.5*cos((-1:0.1:1)*pi);
x = -1.15+0.1*cumsum(dx);
G = tensorGrid(x,sqrt(0:0.05:1));
plotGrid(G,'FaceColor','none'); axis off; drawnow

%% 2.5D PEBI grid using seamount.mat
clf
load seamount % Matlab standard dataset
g = pebi(triangleGrid([x(:) y(:)]));
G = makeLayeredGrid(g, 5);
plotGrid(G), view(-40, 60), axis tight off; drawnow

%% Corner-point grid with a single fault
clf
G = processGRDECL(simpleGrdecl([20, 10, 5], 0.12));
plotGrid(G,'FaceAlpha',0.8);
plotFaces(G,find(G.faces.tag>0),'FaceColor','red');
view(40,40), axis tight off; drawnow

%% A realistic geological model from the SAIGUP study
% We assume that the data set has been downloaded and placed in a standard
% path (as described on the page from which it can be downloaded)
clf
grdecl = readGRDECL(fullfile(ROOTDIR, 'examples', 'data', ...
   'SAIGUP','SAIGUP.GRDECL'));
G = processGRDECL(grdecl);
plotGrid(G,'EdgeAlpha',0.1); view(-80,50), axis tight off
