%% Figure 3: Examples of Petrophysical Parameters
% This script produces two plots that show petrophysical parameters and
% thereby demonstrates how to make such data.

%% Porosity from the Carman-Kozeny relation
clf
G = cartGrid([50 20]);
p = gaussianField(G.cartDims, [0.2 0.4], [11 3], 2.5); p = p(:);
rock.poro = p;
rock.perm = p.^3.*(1e-5)^2./(0.81*72*(1-p).^2);
plotCellData(G,rock.poro); axis tight
h=colorbar('SouthOutside'); drawnow

%% Lognormal layered permeability
clf
G = processGRDECL(simpleGrdecl([50 30 10], 0.12));
K = logNormLayers(G.cartDims, [100 400 50 350], 'indices', [1 2 5 7 11]);
plotCellData(G,log10(K),'EdgeColor','k'); view(45,30);
axis tight off, set(gca,'DataAspect',[0.5 1 1])
h=colorbar('horiz'); ticks=25*2.^[0:5];
set(h,'XTick',log10(ticks),'XTickLabel',ticks);
