function p = callMetis(G, n, sti)
% Call 'kmetis' to partition a grid
%
% SYNOPSIS:
%   p = callMetis(G, n)
%   p = callMetis(G, n, path)
%
% PARAMETERS:
%   G    - Grid data structure
%   n    - number of coarse blocks in partition
%   path - path to the 'kmetis' executable
%
% RETURNS:
%   p    - partition vector, cell i is block j if p(i)=j
%
% SEE ALSO:
%   partitionCartGrid, partitionUI, processPartition, generateCoarseGrid

%{
#COPYRIGHT#
%}

   if nargin<3, sti = './'; end
   
   i = all(G.faces.neighbors>0, 2);
   adj = sort(G.faces.neighbors(i,:),2);
   adj = sortrows([adj;adj(:,[2,1])]);
   nv = max(adj(:));
   ne = sum(i);
   
   name = tempname;
   fp = fopen(name,'w');
   fprintf(fp, '%d %d\n', nv, ne);
   for k=1:size(adj,1)-1,
      row = adj(k,1);
      fprintf(fp, '%d ', adj(k,2));
      if adj(k+1,1)~=row,
         fprintf(fp, '\n');
      end
   end
   fprintf(fp, '%d ', adj(end,2));
   fclose(fp);
   system(sprintf('%skmetis %s %d',sti, name, n))
   p = load(sprintf('%s.part.%d', name, n))+1;
   system(sprintf('rm %s.part.%d', name, n));
   system(sprintf('rm %s', name));
end